#### General comment

Jaminjung belongs to the small Jaminjungan (or Western Mirndi) subgroup of the
geographically discontinuous Mirndi family, one of the non-Pama-Nyungan families
of northern Australia. The name Jaminjung is used here for two named varieties,
Jaminjung and Ngaliwurru, which are mutually intelligible and exhibit mainly
lexical differences. The traditional country of Jaminjung and Ngaliwurru
speakers is located north and south of the Victoria River around the present-day
township of Timber Creek in the Northern Territory. Jaminjung is severely
endangered in that it is no longer acquired by children; only a few dozen
elderly speakers are alive today.

A pervasive feature of Jaminjung lexicon and grammar, which proves to be highly
relevant for the discussion of verb classes and alternations, is a division of
the “verbal” lexicon into two distinct parts of speech. This is an areal
phenomenon found in a number of unrelated languages in Northern Australia.

Inflecting verbs (IVs), i.e. those taking obligatory pronominal prefixes and
tense and mood marking, form a closed class with only about 35 members (with
some variation depending on the dialect affiliation and also the age of
individual speakers).

Uninflecting verbs (UVs; also known as "coverbs" or "preverbs" in the
literature) can be distinguished from IVs by the fact that they cannot take
verbal inflections. They are also distinguishable from nominals in that they do
not co-occur with determiners such as demonstratives. UVs form an open class
which can be expanded by loan words.

Predicates in Jaminjung thus can be simple (an IV on its own) or complex (a
combination of an IV and one or two UVs). In addition, translation equivalents
of verbs can be collocations involving nominals, e.g. expressions with a body
part for feelings/pain, or expressions like gugu gardbany 'rain falls' = 'to
rain'.

Most valency alternations in Jaminjung are only relevant for complex predicates.
A valency change in this type of alternation is achieved by combining the same
UV with different IVs resulting e.g. in inchoative vs. causative complex
predicates. In this database, they are therefore marked as "UV" preceding the
alternation name, and are considered coded alternations even though they are not
coded by a dedicated valency-changing morphological marker. Note also that the
substitution of different IVs with the same UV can also result in other semantic
differences, e.g. in lexical aspect, deictic direction of motion, instrument
used for contact, or other more subtle differences. In this database only
valency-changing alternations are considered.

#### Characterization of flagging resources

Jaminjung has a rich system of cases which formally are clitics occurring once
or more than once in a phrase. Case marking of core arguments follows an
ergative-absolutive pattern, with optional ergativity. As a general rule, the
case frame used with a particular predicate, whether simple or complex, follows
from the morphological transitivity of the inflecting verb (IV). That is,
a single absolutive argument occurs with intransitive IVs, and an
ergative-absolutive case frame (or double absolutive if ergative marking is
omitted) is used with transitive IVs. Since the absolutive is unmarked, it is
not glossed in examples. The ergative has the form -ni ~ -di.

Ergative marking of A arguments is optional in Jaminjung; the presence vs.
absence of ergative marking depends on a variety of factors including the
semantics of the predicate, animacy and degree of agentivity of A, and lexical
and grammatical aspect. Therefore, presence vs. absence of ergative marking was
not considered an alternation for the purposes of this database.

Regular double absolutive marking used for both A and P of some bivalent atelic
predicates (with intransitive IV), i.e. the ergative is not possible on As in
this case.

Double absolutive marking is also used for both NP objects of a semantically
trivalent predicate.

Dative case ( -gu ~ -wu) marks addressees or beneficiaries and also has
a purposive function; in addition a specialised purposive case (-ngurlung) is
used by some speakers, and the possessive case -gina (usually appearing in
adnominal function) can have a purposive use as well.

Spatial cases are locative (-gi ~ -g ~ -ni), allative (-bina) and ablative
(-ngunyi / -giyag). Specialised forms of these cases are found on inherently
locative expressions. An additional origin case (-nyunga) indicates spatial
origin (as in 'the man from England') but also has a causal function.

#### Characterization of indexing resources

From the point of view of indexing morphology, inflecting verbs (IVs) fall into
two non-overlapping classes. Morphologically transitive verbs in their
non-reflexive/reciprocal form occur with a set of pronominal prefixes which
always index the most agentive argument (A) and in addition the patient-like (P)
argument. With ditransitive predicates, R rather than P is usually indexed
except for a marginal alternation which is possible only in the case that P is
animate.

The order of prefixes is usually A followed by P, although in some cases
a portmanteau prefix is used. The 3rd person singular object (P) is not overtly
expressed except with a 3rd person singular subject.

In one variety, nonsingular first person P prefixes have been neutralised, i.e.
only the first person singular prefix is used, and an enclitic pronominal
(identical to the dative form) is used to disambiguate for number and the
inclusive/exclusive distinction.

Morphologically intransitive verbs indicate their single argument (S) by
a pronominal prefix which in most cells of the paradigm (except 2nd person
singular) is identical to the A prefix. Thus, indexing more or less follows
a nominative-accusative pattern.

A final indexing phenomenon is the cross-referencing of dative, locative and
allative arguments or adjuncts by an enclitic oblique (dative) pronoun. This
“clitic doubling” is restricted to animate referents.

#### Characterization of ordering resources

Word order is purely pragmatically conditioned and not employed to indicate
grammatical roles. Noun phrases can be freely omitted if understood from context
(zero anaphora).

#### Source of the data and generalizations/background of the contributor(s)

Data in this database are from both elicited and naturalistic speech recorded
during multiple field trips undertaken by the author between 1993 and 2008.
Occasional examples also come from field notes and texts recorded by Mark
Harvey, Janet Bolt, and Michael Walsh, and Dorothea Hoffmann. Examples from
audio- or video-recorded sessions are accompanied by the file name of the audio
file as archived (with annotations) in the Jaminjung DoBeS archive
(www.mpi.nl/dobes) (rather than a page nr). Examples marked as "field notes" are
overheard examples. Examples with no file name information come from transcripts
which are not yet linked to archived audio files.

Comments on conventions:

In literal glosses of complex verbs in the "comments" field, the gloss of the
inflecting verb (IV) is in capitals.

Since there is no infinitive form of the inflecting verb in Jaminjung and roots
are not produced in isolation by speakers, the 3rd singular subject (+ 3rd sg
object for tr.verbs) past perfective form of inflecting verbs is provided
throughout, as this is one of the most frequent forms.

Borrowings (in verb meanings) and code switches (in examples) from Kriol, the
English-lexified Creole language spoken by most Jaminjung speakers, are marked
by angular brackets (<...>).
