#### General comment

Korean is spoken by approximately 70 million (Lee and Ramsey 2000: 1, Yeon 2003:
17) people mainly on the Korean peninsula. Many varieties exist also outside the
peninsula, reaching from Northern China far out to Central Asia. This database
shows valency properties of Modern South Korean (henceforth Korean, see also
discussion below) which is based on the dialect of Seoul (see Song 2012),
although contrary to standard sources such as Sohn (1999), an emphasis has been
put on what is commonly used in spoken usage.

Korean is an agglutinating language with a basic word order often stated as SOV,
although it may be flexible depending on information structure and discourse
factors. Word order may become less flexible as soon as case markers are
dropped, and whenever there are double nominative or double accusative
constructions (see comments on ordering resources though).

The genetic affiliation of Korean is notoriously disputed, with three different
main stances on this: The first stance is that Korean is an Altaic language (Lee
2008), the second that it might be distantly related to Japanese (Lee and Ramsey
2000), and the third that it is simply a language isolate (Sohn 1999).
Especially the latter suggestion is highly misleading:

Firstly, monographs such as Lee and Ramsey 2000 explain that it is probable that
multiple related languages were spoken by ancient kingdoms, and probably the
language of Shilla gave rise to what is now considered Korean. However, data
seems to be scarce and not much can be said about the different languages spoken
on the Korean peninsula during that period.

Secondly, a huge deal of socio-politically motivated language ideology is
obvious, yet far too often overlooked in Korean linguistics (and beyond), and it
is curious that with 'Korean' we almost always refer to Modern Standard South
Korean. Prescriptive movements and over-standardisation (see Park 2010) seems to
be a popular sociolinguistic practice fed by nationalism and high pride of one's
own language. As a consequence, regional variation is commonly downplayed within
Korean linguistics, and as a result, material on variation of Korean covers
relatively few linguistic areas and is generally very dense (see King 2006, for
example).

The past years have seen an ongoing change of perception, at least in
non-capital parts of Korea as well as international linguistics. Although not
widely acknowledged yet, Jeju spoken in Jeju Province has been classified as
a critically endangered language (Moseley 2010), and renowned figures in the
field of endangered languages and Korean linguistics (Matthias Brenzinger, p.c.
and William O'Grady, p.c.) support the view that Korean is only a language
isolate by ideology, but not by empirical fact, since it should more
appropriately seen as constituting a small Koreanic language family of at least
two languages (see Kang 2007 for a rough sketch of Korean's little sister
language Jeju).

#### Characterization of flagging resources

Korean uses case marking to flag verbal arguments. Syntactically, case markers
may be affixed to simple nouns and noun phrases. The syntactic status of case
markers is disputed, with some counting them all as postpositions (see Yeon
2003: 22 or Sohn 1999: 293 for an overview); and also the number of different
cases is not agreed upon. Case stacking is possible on nouns. Case markers are
commonly dropped in colloquial speech and give rise to certain ambiguities. The
differences between colloquial and literary Korean have not been acknowledged
enough in the literature, and some of the content of this database might seem
wrong to some scholars who have been trained in a Korean schooling system. The
appearance of nominative and accusative case markers may depend on discourse
factors similar to differential argument marking (see Lee and Thompson 1989, as
one of few studies), with more extreme (but certainly more interesting) studies
suggesting that Korean 'case' markers might not be case markers at all (cf.
Schütze 2001).

Note that with respect to the dative case marking, there seems to be sort of
a differential marking in Korean where only animate nouns can receive dative
marking, and inanimate nouns in corresponding functions receive locative
marking.

#### Characterization of indexing resources

Korean verbs do not inflect with respect to person, number or gender. A special
case might be the agglutination of the honorific suffix -si- which is coreferent
with an A or S argument, and never co-occurs with the first person being the
subject of a verb due to sociolinguistic motivations.

#### Characterization of ordering resources

Many scholars (for example Yeon 2003: 18 or Sohn 1999: 293) see Korean as
a scrambling language where the order of constituents is fairly free as long as
the predicate comes last. This conclusion has been drawn on the simple
observation that as long as every NP in a sentence bears case marking, putting
the constituents in different order does not seem to lead to ungrammaticality.

From the viewpoint of how Korean is actually used, the generalisations on Korean
word order are far too simplistic. As shown in a few examples in this database,
for example one in the layout for GIVE, case markers are not employed as often
as a reference grammar might suggest, and the lack of case marking on NPs often
leads to strict word order. Furthermore, in cases where we have double
nominative or double accusative constructions the word order of the verbal
arguments is fairly fixed. There are interesting studies on Japanese however
(cf. Hinds 1981) which suggest that this 'fixed' word order might exist only in
the 'intuition' of a native speaker (or more specifically, my humble self),
since it has been reported that Japanese grammarians frequently utter the same
thread of thought, although actual spoken Japanese shows that the abovementioned
word order variations might well be possible under certain conditions.

As Sohn (1999: 293) himself mentions, "in actual utterances, a speaker tends to
place an animate, definite and/or specific noun phrase before the other noun
phrases", and observing 'free word order' in Korean should rather be taken with
a pinch of salt.

Also, Korean word order and case marking seems to ineract in a very complex way
with information structure, referentiality and definiteness. This is an area
that has been widely neglected in the study of Korean. The study of these areas
should show that Korean word order is by far not that 'liberal' as is constantly
reiterated in grammatical descriptions.

#### Criteria used when judging if an alternation occurs regularly/marginally/never

"Regularly" means that a verb in the alternated form under discussion is
grammatically acceptable and common to me. "Marginally" means that subjectively,
I have not come across these constructions very frequently, or that a verb in
this alternation sounds quite odd, maybe because I would not use the verb that
way but rather use an alternative paraphrase. It can also mean that I am simply
not sure if you can say that this way because I have never had the need to. As
you can see, verbs marked as "marginally" are marked as such more various
reasons which may depend more on my individual meta-linguistic judgment. For
this reason I have always tried to avoid ticking this option as much as I could.

#### Source of the data and generalizations/background of the contributor(s)

The data is based on introspection of the contributor (Soung-U Kim),
a German-born male linguist of Korean descent, as well as on the grammatical
judgment of two persons consulted for his BA thesis (completed in 2011), with
two other persons consulted in 2013/2014 during the elaboration of this
database. Whenever the grammatically of an expression does not seem to be
universally acceptable, I indicated it in the comment field. Sometimes I googled
the existence of some forms I use (in order to maximally exclude idiolectal and
bilingual interference), but I am aware that this method may have its pitfalls
as well and should be seen under a sceptical eye. Note that although I did not
receive Korean schooling, I spent several years in Korea as a child, with
Southern Jeolla Korean being my L1. I am well aware of the problems of data
collection through introspection, and surely studies on Korean with a much
greater range of native speakers (who have grown up in Seoul) will show much
more reliable data than the present set. I hope that the present database can
rather give some 'nudges' into directions of more sophisticated research.

A lot of 'verb entries' are either complex predicates or tend to be used as
such, and I have given some information in each entry. As mentioned, a special
emphasis has been put on the naturalness of certain verb forms and constructions
(see FRIGHTEN, for example), and contrary to well-known sources such as Yeon
(2003) I have decided basic coding patterns rather following my intuition on the
naturalness of a construction in informal usage, and several examples show
spoken Korean which differs quite strongly from the Korean normally shown in
grammars.

The transcription of Korean follows the regulations of the Revised Romanisation
of 2000. Primary texts in examples indicate the actual pronunciation of Korean
morphemes (largely excluding phonological changes happening across wod
boundaries), with the spacing following the Korean script. The analyzed text
strictly follows a phonemic representation, which also applies to the verb
entries. The glossing follows the Leipzig Glossing rules. The original script
fields sometimes contain differently romanised examples from existing monographs
in English.

Personal pronouns only exist for 1st and 2nd person. However, for third person
demonstratives sometimes I have chosen 3SG as their gloss since demostratives in
Korean can be quite complex, involving a three-way distinction into proximal,
medial and distal, and behaving much like nouns in terms of the affixes they can
take on.

Whenever a verb is discussed here that is actually included in the database,
I tried to write it in capital letters. 
